<?php
/**
 * Headline Theme Customizer
 *
 * @package Headline
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function headline_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'headline_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'headline_customize_partial_blogdescription',
		) );
	}
	
	
	/**
	 * Theme options.
	 */
	
	// Section
	$wp_customize->add_section(
		'headline_section', array(
			'title' => esc_html__('Theme Options', 'headline'), 
			'priority' => 2 
		)
	);
	// Setting
	$wp_customize->add_setting(
		'blog_display', array(
			'default' => 'the_content', 
			'sanitize_callback' => 'headline_sanitize_select'
		)
	);
	// Control
	$wp_customize->add_control(
		'blog_display', array(
			'label' => esc_html__('Layout Type', 'headline'), 
			'section' => 'headline_section', 
			'settings' => 'blog_display', 
			'priority' => 1, 
			'type' => 'select', 
			'choices' => array('the_excerpt' => esc_html__('the_excerpt', 'headline'), 
			'the_content' => esc_html__('the_content', 'headline'))
		)
	);
	
	// Collor Style
	// Setting
	$wp_customize->add_setting(
		'color_style', array(
			'default' => 'hdl-orange', 
			'sanitize_callback' => 'headline_sanitize_select'
		)
	);
	// Control
	$wp_customize->add_control(
		'color_style', array(
			'label' => esc_html__('Color Schema', 'headline'), 
			'section' => 'headline_section', 
			'settings' => 'color_style', 
			'priority' => 1, 
			'type' => 'select', 
			'choices' => array('hdl-orange' => esc_html__('Orange', 'headline'), 
			'hdl-red' => esc_html__('Red', 'headline'),
			'hdl-blue' => esc_html__('Blue', 'headline'))
		)
	);
	
	
}
add_action( 'customize_register', 'headline_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function headline_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function headline_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function headline_customize_preview_js() {
	wp_enqueue_script( 'headline-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'headline_customize_preview_js' );


if (!function_exists('headline_sanitize_select')) {
	function headline_sanitize_select($input) {
		return wp_filter_nohtml_kses( $input );
	}
}